@@ -3,7 +3,7 @@
 ##
 ##    Functions for generating random point patterns
 ##
-##    $Revision: 4.117 $   $Date: 2023/09/25 03:10:32 $
+##    $Revision: 4.124 $   $Date: 2025/03/15 03:40:12 $
 ##
 ##    runifpoint()      n i.i.d. uniform random points ("binomial process")
 ##    runifdisc()       special case of disc (faster)
@@ -78,7 +78,7 @@ runifpoint <- function(n, win=owin(c(0,1),c(0,1)),
     W <- Window(win)
     pieces <- tiles(win)
     ntiles <- length(pieces)
-    check.nvector(n, ntiles, things="tiles", oneok=TRUE)
+    check.nvector(n, ntiles, things="tiles", oneok=TRUE, vname="n")
     if(length(n) == 1) n <- rep(n, ntiles)
     Y <- mapply(runifpoint, n=n, win=pieces,
                 MoreArgs=list(nsim=nsim, drop=FALSE, giveup=giveup, warn=warn),
@@ -388,8 +388,17 @@ rpoispp <- function(lambda, lmax=NULL, win = owin(), ...,
     check.1.integer(nsim)
     stopifnot(nsim >= 0)
   }
+
+  if(!missing(lambda) && inherits(lambda, "tessfun")) {
+    ## intensity is constant on each tile of a tessellation
+    ## use special algorithm
+    if(missing(win)) win <- NULL
+    result <- rpoisTessfun(lambda, win=win, nsim=nsim, drop=drop, ...)
+    return(result)
+  }
   
   if(missing(lambda) && is.null(lmax) && missing(win) && !is.null(ex)) {
+    ## use example pattern 'ex'
     lambda <- intensity(unmark(ex))
     win <- Window(ex)
   } else {
@@ -494,6 +503,58 @@ rpoispp <- function(lambda, lmax=NULL, win = owin(), ...,
   stop(paste(sQuote("lambda"), "must be a constant, a function or an image"))
 }
     
+rpoisTessfun <- function(lambda, win=NULL, ..., nsim=1, drop=TRUE,
+                         tilewise=NULL, verbose=TRUE) {
+  ## special case of rpoispp: constant intensity on each tile of tessellation
+  stopifnot(inherits(lambda, "tessfun"))
+  tes <- as.tess(lambda)
+  lam <- as.numeric(tessfunvalues(lambda))
+  lmax <- max(lam)
+  Wfull <- Window(as.tess(lambda))
+  if(is.null(win)) win <- Wfull else stopifnot(is.owin(win))
+  if(length(tilewise) == 0) {
+    ## decide which algorithm to use
+    switch(tes$type,
+           rect = ,
+           tiled = {
+             En <- integral(lambda)
+             Em <- lmax * area(Wfull)
+             tilewise <- (Em > .Machine$integer.max) || (En < Em/1e3)
+             if(verbose)
+               message("Using ", if(tilewise) "tilewise" else "rejection",
+                       " algorithm")
+           },
+           image = {
+             ## No benefit in splitting by tiles
+             tilewise <- FALSE
+           })
+  }
+  if(isFALSE(tilewise)) {
+    ## use rejection algorithm 
+    class(lambda) <- setdiff(class(lambda), "tessfun")
+    result <- rpoispp(lambda, lmax=lmax, win=win, ..., nsim=nsim, drop=drop)
+    return(result)
+  }
+  B <- Frame(win)
+  til <- tiles(tes)
+  nt <- length(til)
+  for(j in seq_len(nt)) {
+    ## generate 'nsim' patterns in tile 'j'
+    Uj <- runifpoispp(lam[j], til[[j]], nsim=nsim, drop=FALSE)
+    ## extract coordinates as list(list(x,y), list(x,y), ...)
+    if(j == 1) {
+      xylist <- lapply(Uj, concatxy)
+    } else {
+      xylist <- mapply(concatxy, xylist, Uj, SIMPLIFY=FALSE)
+    }
+  }
+  ## create point pattern objects
+  result <- lapply(xylist, as.ppp, W=B, check=FALSE)
+  ## clip to 'win'
+  result <- lapply(result, "[", i=win)
+  return(simulationresult(result, nsim, drop))
+}
+
 rMaternI <- function(kappa, r, win = owin(c(0,1),c(0,1)), stationary=TRUE,
                      ..., nsim=1, drop=TRUE)
 {
@@ -577,7 +638,7 @@ rMaternInhibition <- function(type,
 rSSI <- function(r, n=Inf, win = square(1), 
                  giveup = 1000, x.init=NULL, ...,
                  f=NULL, fmax=NULL,
-                 nsim=1, drop=TRUE)
+                 nsim=1, drop=TRUE, verbose=TRUE)
 {
   win.given <- !missing(win) && !is.null(win)
   stopifnot(is.numeric(r) && length(r) == 1 && r >= 0)
@@ -587,6 +648,8 @@ rSSI <- function(r, n=Inf, win = square(1),
     check.1.integer(nsim)
     stopifnot(nsim >= 1)
   }
+  ## 'verbose' applies only when nsim > 1
+  verbose <- verbose && (nsim > 1)
   ##
   if(!is.null(f)) {
     stopifnot(is.numeric(f) || is.im(f) || is.function(f))
@@ -656,8 +719,9 @@ rSSI <- function(r, n=Inf, win = square(1),
 
   #' start simulation 		    
   pstate <- list()
+  if(verbose) splat("Generating", nsim, "realisations...")
   for(isim in seq_len(nsim)) {
-    if(nsim > 1) pstate <- progressreport(isim, nsim, state=pstate)
+    if(verbose) pstate <- progressreport(isim, nsim, state=pstate)
     ## Simple Sequential Inhibition process
     ## fixed number of points
     xx <- coords(x.init)$x
@@ -740,7 +804,7 @@ rPoissonClusterEngine <- function(kappa, expand=rmax, rcluster, win, ...,
   ## Generate parents in dilated window
   win <- as.owin(win)
   frame <- boundingbox(win)
-  dilated <- owin(frame$xrange + c(-expand, expand),
+  dilated <- owinInternalRect(frame$xrange + c(-expand, expand),
                   frame$yrange + c(-expand, expand))
 
   if(is.im(kappa) && !is.subset.owin(dilated, as.owin(kappa)))
