@@ -2,7 +2,7 @@
 #
 #   rmhmodel.R
 #
-#   $Revision: 1.80 $  $Date: 2022/01/03 08:01:37 $
+#   $Revision: 1.84 $  $Date: 2024/06/09 00:19:27 $
 #
 #
 
@@ -405,8 +405,8 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the Poisson process"
-              with(par, forbidNA(beta, ctxt))
-              par <- check.named.list(par, "beta", ctxt)
+              with(par, forbidNA(beta, ctxt, xname="beta"))
+              par <- check.named.list(par, "beta", ctxt, xtitle="par")
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               return(par)
             },
@@ -429,12 +429,13 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the strauss cif"
-              par <- check.named.list(par, c("beta","gamma","r"), ctxt)
+              par <- check.named.list(par, c("beta","gamma","r"), 
+				      ctxt, xtitle="par")
               # treat r=NA as absence of interaction
               par <- within(par, if(is.na(r)) { r <- 0; gamma <- 1 })
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(gamma, ctxt))
-              with(par, check.finite(r, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(gamma, ctxt, "gamma"))
+              with(par, check.finite(r, ctxt, "r"))
               with(par, check.1.real(gamma, ctxt))
               with(par, check.1.real(r,     ctxt))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
@@ -478,15 +479,16 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the straush cif"
-              par <- check.named.list(par, c("beta","gamma","r","hc"), ctxt)
+              par <- check.named.list(par, c("beta","gamma","r","hc"), 
+                                      ctxt, xtitle="par")
               # treat hc=NA as absence of hard core
               par <- within(par, if(is.na(hc)) { hc <- 0 } )
               # treat r=NA as absence of interaction
               par <- within(par, if(is.na(r)) { r <- hc; gamma <- 1 } )
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(gamma, ctxt))
-              with(par, check.finite(r, ctxt))
-              with(par, check.finite(hc, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(gamma, ctxt, "gamma"))
+              with(par, check.finite(r, ctxt, "r"))
+              with(par, check.finite(hc, ctxt, "hc"))
               with(par, check.1.real(gamma, ctxt))
               with(par, check.1.real(r,     ctxt))
               with(par, check.1.real(hc,     ctxt))
@@ -536,10 +538,11 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the sftcr cif"
-              par <- check.named.list(par, c("beta","sigma","kappa"), ctxt)
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(sigma, ctxt))
-              with(par, check.finite(kappa, ctxt))
+              par <- check.named.list(par, c("beta","sigma","kappa"),
+                                      ctxt, xtitle="par")
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(sigma, ctxt, "sigma"))
+              with(par, check.finite(kappa, ctxt, "kappa"))
               with(par, check.1.real(sigma, ctxt))
               with(par, check.1.real(kappa, ctxt))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
@@ -583,26 +586,26 @@ spatstatRmhInfo <- function(cifname) {
             multitype=TRUE,
             parhandler=function(par, types) {
               ctxt <- "For the straussm cif"
-              par <- check.named.list(par, c("beta","gamma","radii"), ctxt)
-
+              par <- check.named.list(par, c("beta","gamma","radii"),
+                                      ctxt, xtitle="par")
               beta <- par$beta
               gamma <- par$gamma
               r <- par$radii
               ntypes <- length(types)
 
-              check.finite(beta, ctxt)
-              check.nvector(beta, ntypes, TRUE, "types")
+              check.finite(beta, ctxt, "beta")
+              check.nvector(beta, ntypes, TRUE, "types", vname="beta")
 
               MultiPair.checkmatrix(gamma, ntypes, "par$gamma")
 	      gamma[is.na(gamma)] <- 1
-              check.finite(gamma, ctxt)
+              check.finite(gamma, ctxt, "gamma")
 
               MultiPair.checkmatrix(r, ntypes, "par$radii")
               if(any(nar <- is.na(r))) {
                 r[nar] <- 0
                 gamma[nar] <- 1
               }
-              check.finite(r, ctxt)
+              check.finite(r, ctxt, "r")
 
               explain.ifnot(all(beta >= 0), ctxt)
               explain.ifnot(all(gamma >= 0), ctxt)
@@ -656,32 +659,31 @@ spatstatRmhInfo <- function(cifname) {
               ctxt="For the straushm cif"
               par <- check.named.list(par,
                                       c("beta","gamma","iradii","hradii"),
-                                      ctxt)
-
+                                      ctxt, xtitle="par")
               beta <- par$beta
               gamma <- par$gamma
               iradii <- par$iradii
               hradii <- par$hradii
               ntypes <- length(types)
 
-              check.nvector(beta, ntypes, TRUE, "types")
-              check.finite(beta, ctxt)
+              check.nvector(beta, ntypes, TRUE, "types", vname="beta")
+              check.finite(beta, ctxt, "beta")
               
               MultiPair.checkmatrix(gamma, ntypes, "par$gamma")
               gamma[is.na(gamma)] <- 1
-              check.finite(gamma, ctxt)
+              check.finite(gamma, ctxt, "gamma")
 
               MultiPair.checkmatrix(iradii, ntypes, "par$iradii")
               if(any(nar <- is.na(iradii))) {
                 iradii[nar] <- 0
                 gamma[nar] <- 1
               }
-              check.finite(iradii, ctxt)
+              check.finite(iradii, ctxt, "iradii")
 
               MultiPair.checkmatrix(hradii, ntypes, "par$hradii")
               nah <- is.na(hradii)
               hradii[nah] <- 0
-              check.finite(hradii, ctxt)
+              check.finite(hradii, ctxt, "hradii")
 
               explain.ifnot(all(beta >= 0), ctxt)
               explain.ifnot(all(gamma >= 0), ctxt)
@@ -748,9 +750,10 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the dgs cif"
-              par <- check.named.list(par, c("beta","rho"), ctxt)
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(rho, ctxt))
+              par <- check.named.list(par, c("beta","rho"),
+                                      ctxt, xtitle="par")
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(rho, ctxt, "rho"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               with(par, check.1.real(rho, ctxt))
               with(par, explain.ifnot(rho >= 0, ctxt))
@@ -782,11 +785,11 @@ spatstatRmhInfo <- function(cifname) {
             parhandler=function(par, ...) {
               ctxt <- "For the diggra cif"
               par <- check.named.list(par, c("beta","kappa","delta","rho"),
-                                      ctxt)
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(kappa, ctxt))
-              with(par, check.finite(delta, ctxt))
-              with(par, check.finite(rho, ctxt))
+                                      ctxt, xtitle="par")
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(kappa, ctxt, "kappa"))
+              with(par, check.finite(delta, ctxt, "delta"))
+              with(par, check.finite(rho, ctxt, "rho"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               with(par, check.1.real(kappa, ctxt))
               with(par, check.1.real(delta, ctxt))
@@ -823,16 +826,18 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the geyer cif"
-              par <- check.named.list(par, c("beta","gamma","r","sat"), ctxt)
+              par <- check.named.list(par,
+                                      c("beta","gamma","r","sat"),
+                                      ctxt, xtitle="par")
               with(par, check.1.real(gamma, ctxt))
               with(par, check.1.real(r,     ctxt))
               with(par, check.1.real(sat,   ctxt))
               par <- within(par, sat <- min(sat, .Machine$integer.max-100))
               par <- within(par, if(is.na(gamma)) { r <- 0; gamma <- 1 })
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(gamma, ctxt))
-              with(par, check.finite(r, ctxt))
-              with(par, check.finite(sat, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(gamma, ctxt, "gamma"))
+              with(par, check.finite(r, ctxt, "r"))
+              with(par, check.finite(sat, ctxt, "sat"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               return(par)
             },
@@ -873,8 +878,10 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the lookup cif"
-              par <- check.named.list(par, c("beta","h"), ctxt, "r")
-              with(par, check.finite(beta, ctxt))
+              par <- check.named.list(par,
+                                      c("beta","h"),
+                                      ctxt, "r", xtitle="par")
+              with(par, check.finite(beta, ctxt, "beta"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               beta   <- par[["beta"]]
               h.init <- par[["h"]]
@@ -982,14 +989,15 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the areaint cif"
-              par <- check.named.list(par, c("beta","eta","r"), ctxt)
+              par <- check.named.list(par, c("beta","eta","r"),
+                                      ctxt, xtitle="par")
               par <- within(par, if(is.na(r)) { r <- 0 })
-              with(par, check.finite(beta, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               with(par, check.1.real(eta, ctxt))
               with(par, check.1.real(r,   ctxt))
-              with(par, check.finite(eta, ctxt))
-              with(par, check.finite(r,   ctxt))
+              with(par, check.finite(eta, ctxt, "eta"))
+              with(par, check.finite(r,   ctxt, "r"))
               with(par, explain.ifnot(eta >= 0, ctxt))
               with(par, explain.ifnot(r >= 0,   ctxt))
               return(par)
@@ -1029,14 +1037,16 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the badgey cif"
-              par <- check.named.list(par, c("beta","gamma","r","sat"), ctxt)
+              par <- check.named.list(par,
+                                      c("beta","gamma","r","sat"),
+                                      ctxt, xtitle="par")
               par <- within(par, sat <- pmin(sat, .Machine$integer.max-100))
               par <- within(par, gamma[is.na(gamma) | is.na(r)] <- 1)
               par <- within(par, r[is.na(r)] <- 0)
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(gamma, ctxt))
-              with(par, check.finite(r, ctxt))
-              with(par, check.finite(sat, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(gamma, ctxt, "gamma"))
+              with(par, check.finite(r, ctxt, "r"))
+              with(par, check.finite(sat, ctxt, "sat"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               with(par, explain.ifnot(all(gamma >= 0), ctxt))
               with(par, explain.ifnot(all(r >= 0), ctxt))
@@ -1085,10 +1095,10 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the hardcore cif"
-              par <- check.named.list(par, c("beta", "hc"), ctxt)
+              par <- check.named.list(par, c("beta", "hc"), ctxt, xtitle="par")
               par <- within(par, if(is.na(hc)) { hc <- 0 })
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(hc, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(hc, ctxt, "hc"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               with(par, check.1.real(hc, ctxt))
               return(par)
@@ -1124,12 +1134,12 @@ spatstatRmhInfo <- function(cifname) {
               ctxt <- "For the Fiksel cif"
               par <- check.named.list(par,
                                       c("beta", "r", "hc", "kappa", "a"),
-                                      ctxt)
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(r, ctxt))
-              with(par, check.finite(hc, ctxt))
-              with(par, check.finite(kappa, ctxt))
-              with(par, check.finite(a, ctxt))
+                                      ctxt, xtitle="par")
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(r, ctxt, "r"))
+              with(par, check.finite(hc, ctxt, "hc"))
+              with(par, check.finite(kappa, ctxt, "kappa"))
+              with(par, check.finite(a, ctxt, "a"))
               with(par, check.1.real(r, ctxt))
               with(par, check.1.real(hc, ctxt))
               with(par, check.1.real(kappa, ctxt))
@@ -1175,10 +1185,10 @@ spatstatRmhInfo <- function(cifname) {
               ctxt <- "For the Lennard-Jones cif"
               par <- check.named.list(par,
                                       c("beta", "sigma", "epsilon"),
-                                      ctxt)
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(sigma, ctxt))
-              with(par, check.finite(epsilon, ctxt))
+                                      ctxt, xtitle="par")
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(sigma, ctxt, "sigma"))
+              with(par, check.finite(epsilon, ctxt, "epsilon"))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
               with(par, check.1.real(sigma, ctxt))
               with(par, check.1.real(epsilon, ctxt))
@@ -1220,18 +1230,18 @@ spatstatRmhInfo <- function(cifname) {
               ctxt="For the multihard cif"
               par <- check.named.list(par,
                                       c("beta","hradii"),
-                                      ctxt)
+                                      ctxt, xtitle="par")
 
               beta <- par$beta
               hradii <- par$hradii
               ntypes <- length(types)
 
-              check.nvector(beta, ntypes, TRUE, "types")
-              check.finite(beta, ctxt)
+              check.nvector(beta, ntypes, TRUE, "types", vname="beta")
+              check.finite(beta, ctxt, "beta")
               
               MultiPair.checkmatrix(hradii, ntypes, "par$hradii")
               hradii[is.na(hradii)] <- 0
-              check.finite(hradii, ctxt)
+              check.finite(hradii, ctxt, "hradii")
 
               explain.ifnot(all(beta >= 0), ctxt)
               explain.ifnot(all(hradii >= 0), ctxt)
@@ -1272,12 +1282,14 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the triplets cif"
-              par <- check.named.list(par, c("beta","gamma","r"), ctxt)
+              par <- check.named.list(par,
+                                      c("beta","gamma","r"),
+                                      ctxt, xtitle="par")
               # treat r=NA as absence of interaction
               par <- within(par, if(is.na(r)) { r <- 0; gamma <- 1 })
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(gamma, ctxt))
-              with(par, check.finite(r, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(gamma, ctxt, "gamma"))
+              with(par, check.finite(r, ctxt, "r"))
               with(par, check.1.real(gamma, ctxt))
               with(par, check.1.real(r,     ctxt))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
@@ -1319,12 +1331,14 @@ spatstatRmhInfo <- function(cifname) {
             multitype=FALSE,
             parhandler=function(par, ...) {
               ctxt <- "For the penttinen cif"
-              par <- check.named.list(par, c("beta", "gamma", "r"), ctxt)
+              par <- check.named.list(par,
+                                      c("beta", "gamma", "r"),
+                                      ctxt, xtitle="par")
               # treat r=NA as absence of interaction
               par <- within(par, if(is.na(r)) { r <- 0; gamma <- 1 })
-              with(par, check.finite(beta, ctxt))
-              with(par, check.finite(gamma, ctxt))
-              with(par, check.finite(r, ctxt))
+              with(par, check.finite(beta, ctxt, "beta"))
+              with(par, check.finite(gamma, ctxt, "gamma"))
+              with(par, check.finite(r, ctxt, "r"))
               with(par, check.1.real(gamma, ctxt))
               with(par, check.1.real(r, ctxt))
               with(par, explain.ifnot(all(beta >= 0), ctxt))
